@@ -12,6 +12,7 @@
 class Category;
 class Feed;
 class Label;
+class Search;
 class ServiceRoot;
 class QAction;
 
@@ -27,11 +28,19 @@ class RSSGUARD_DLLSPEC RootItem : public QObject {
     Q_PROPERTY(QString customId READ customId)
 
   public:
-    enum class ReadStatus { Unread = 0, Read = 1, Unknown = 256 };
+    enum class ReadStatus {
+      Unread = 0,
+      Read = 1,
+      Unknown = 256
+    };
 
     // Holds statuses for messages
     // to be switched importance (starred).
-    enum class Importance { NotImportant = 0, Important = 1, Unknown = 256 };
+    enum class Importance {
+      NotImportant = 0,
+      Important = 1,
+      Unknown = 256
+    };
 
     // Describes the kind of the item.
     enum class Kind {
@@ -43,7 +52,9 @@ class RSSGUARD_DLLSPEC RootItem : public QObject {
       Labels = 32,
       Important = 64,
       Label = 128,
-      Unread = 256
+      Unread = 256,
+      Probes = 512,
+      Probe = 1024
     };
 
     // Constructors and destructors.
@@ -63,17 +74,13 @@ class RSSGUARD_DLLSPEC RootItem : public QObject {
     // Can properties of this item be edited?
     virtual bool canBeEdited() const;
 
-    // Performs editing of properties of this item (probably via dialog)
-    // and returns result status.
-    virtual bool editViaGui();
-
     // Can the item be deleted?
     virtual bool canBeDeleted() const;
 
     // Performs deletion of the item, this
     // method should NOT display any additional dialogs.
     // Returns result status.
-    virtual bool deleteViaGui();
+    virtual bool deleteItem();
 
     // Performs all needed steps (DB update, remote server update)
     // to mark this item as read/unread.
@@ -112,6 +119,8 @@ class RSSGUARD_DLLSPEC RootItem : public QObject {
     RootItem* child(int row);
     int childCount() const;
     void appendChild(RootItem* child);
+
+    QList<RootItem*> childItems(RootItem::Kind kind) const;
     QList<RootItem*> childItems() const;
     QList<RootItem*>& childItems();
 
@@ -147,7 +156,7 @@ class RSSGUARD_DLLSPEC RootItem : public QObject {
     // Returns list of feeds complemented by their own string CUSTOM ID.
     QHash<QString, Feed*> getHashedSubTreeFeeds() const;
 
-    QList<Feed*> getSubTreeFeeds() const;
+    QList<Feed*> getSubTreeFeeds(bool recursive = true) const;
     QList<Feed*> getSubTreeAutoFetchingWithManualIntervalsFeeds() const;
     QList<Feed*> getSubAutoFetchingEnabledFeeds() const;
 
@@ -194,6 +203,7 @@ class RSSGUARD_DLLSPEC RootItem : public QObject {
     Category* toCategory() const;
     Feed* toFeed() const;
     Label* toLabel() const;
+    Search* toProbe() const;
     ServiceRoot* toServiceRoot() const;
 
     bool keepOnTop() const;
